Class: Net::HTTP

Inherits:
Protocol
  • Object
show all
Defined in:
lib/net/http.rb,
lib/net/http/backward.rb

Overview

:enddoc:

Defined Under Namespace

Modules: ProxyDelta Classes: Copy, Delete, Get, Head, Lock, Mkcol, Move, Options, Patch, Post, Propfind, Proppatch, Put, Trace, Unlock

Constant Summary collapse

VERSION =

:stopdoc:

"0.3.1"
Revision =
%q$Revision$.split[1]
HTTPVersion =
'1.1'
SSL_IVNAMES =
[
  :@ca_file,
  :@ca_path,
  :@cert,
  :@cert_store,
  :@ciphers,
  :@extra_chain_cert,
  :@key,
  :@ssl_timeout,
  :@ssl_version,
  :@min_version,
  :@max_version,
  :@verify_callback,
  :@verify_depth,
  :@verify_mode,
  :@verify_hostname,
]
SSL_ATTRIBUTES =
[
  :ca_file,
  :ca_path,
  :cert,
  :cert_store,
  :ciphers,
  :extra_chain_cert,
  :key,
  :ssl_timeout,
  :ssl_version,
  :min_version,
  :max_version,
  :verify_callback,
  :verify_depth,
  :verify_mode,
  :verify_hostname,
]
STATUS_CODES =
{
  100 => 'Continue',
  101 => 'Switching Protocols',
  102 => 'Processing',
  103 => 'Early Hints',
  200 => 'OK',
  201 => 'Created',
  202 => 'Accepted',
  203 => 'Non-Authoritative Information',
  204 => 'No Content',
  205 => 'Reset Content',
  206 => 'Partial Content',
  207 => 'Multi-Status',
  208 => 'Already Reported',
  226 => 'IM Used',
  300 => 'Multiple Choices',
  301 => 'Moved Permanently',
  302 => 'Found',
  303 => 'See Other',
  304 => 'Not Modified',
  305 => 'Use Proxy',
  307 => 'Temporary Redirect',
  308 => 'Permanent Redirect',
  400 => 'Bad Request',
  401 => 'Unauthorized',
  402 => 'Payment Required',
  403 => 'Forbidden',
  404 => 'Not Found',
  405 => 'Method Not Allowed',
  406 => 'Not Acceptable',
  407 => 'Proxy Authentication Required',
  408 => 'Request Timeout',
  409 => 'Conflict',
  410 => 'Gone',
  411 => 'Length Required',
  412 => 'Precondition Failed',
  413 => 'Payload Too Large',
  414 => 'URI Too Long',
  415 => 'Unsupported Media Type',
  416 => 'Range Not Satisfiable',
  417 => 'Expectation Failed',
  421 => 'Misdirected Request',
  422 => 'Unprocessable Entity',
  423 => 'Locked',
  424 => 'Failed Dependency',
  426 => 'Upgrade Required',
  428 => 'Precondition Required',
  429 => 'Too Many Requests',
  431 => 'Request Header Fields Too Large',
  451 => 'Unavailable For Legal Reasons',
  500 => 'Internal Server Error',
  501 => 'Not Implemented',
  502 => 'Bad Gateway',
  503 => 'Service Unavailable',
  504 => 'Gateway Timeout',
  505 => 'HTTP Version Not Supported',
  506 => 'Variant Also Negotiates',
  507 => 'Insufficient Storage',
  508 => 'Loop Detected',
  510 => 'Not Extended',
  511 => 'Network Authentication Required',
}
ProxyMod =
ProxyDelta

Class Attribute Summary collapse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(address, port = nil) ⇒ HTTP

Creates a new Net::HTTP object for the specified server address, without opening the TCP connection or initializing the HTTP session. The address should be a DNS hostname or IP address.



699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
# File 'lib/net/http.rb', line 699

def initialize(address, port = nil)
  @address = address
  @port    = (port || HTTP.default_port)
  @ipaddr = nil
  @local_host = nil
  @local_port = nil
  @curr_http_version = HTTPVersion
  @keep_alive_timeout = 2
  @last_communicated = nil
  @close_on_empty_response = false
  @socket  = nil
  @started = false
  @open_timeout = 60
  @read_timeout = 60
  @write_timeout = 60
  @continue_timeout = nil
  @max_retries = 1
  @debug_output = nil
  @response_body_encoding = false
  @ignore_eof = true

  @proxy_from_env = false
  @proxy_uri      = nil
  @proxy_address  = nil
  @proxy_port     = nil
  @proxy_user     = nil
  @proxy_pass     = nil

  @use_ssl = false
  @ssl_context = nil
  @ssl_session = nil
  @sspi_enabled = false
  SSL_IVNAMES.each do |ivname|
    instance_variable_set ivname, nil
  end
end

Class Attribute Details

.proxy_addressObject (readonly)

Address of proxy host. If Net::HTTP does not use a proxy, nil.



1191
1192
1193
# File 'lib/net/http.rb', line 1191

def proxy_address
  @proxy_address
end

.proxy_passObject (readonly)

User password for accessing proxy. If Net::HTTP does not use a proxy, nil.



1201
1202
1203
# File 'lib/net/http.rb', line 1201

def proxy_pass
  @proxy_pass
end

.proxy_portObject (readonly)

Port number of proxy host. If Net::HTTP does not use a proxy, nil.



1194
1195
1196
# File 'lib/net/http.rb', line 1194

def proxy_port
  @proxy_port
end

.proxy_userObject (readonly)

User name for accessing proxy. If Net::HTTP does not use a proxy, nil.



1197
1198
1199
# File 'lib/net/http.rb', line 1197

def proxy_user
  @proxy_user
end

Instance Attribute Details

#addressObject (readonly)

The DNS host name or IP address to connect to.



755
756
757
# File 'lib/net/http.rb', line 755

def address
  @address
end

#ca_fileObject

Sets path of a CA certification file in PEM format.

The file can contain several CA certificates.



927
928
929
# File 'lib/net/http.rb', line 927

def ca_file
  @ca_file
end

#ca_pathObject

Sets path of a CA certification directory containing certifications in PEM format.



931
932
933
# File 'lib/net/http.rb', line 931

def ca_path
  @ca_path
end

#certObject

Sets an OpenSSL::X509::Certificate object as client certificate. (This method is appeared in Michal Rokos’s OpenSSL extension).



935
936
937
# File 'lib/net/http.rb', line 935

def cert
  @cert
end

#cert_storeObject

Sets the X509::Store to verify peer certificate.



938
939
940
# File 'lib/net/http.rb', line 938

def cert_store
  @cert_store
end

#ciphersObject

Sets the available ciphers. See OpenSSL::SSL::SSLContext#ciphers=



941
942
943
# File 'lib/net/http.rb', line 941

def ciphers
  @ciphers
end

#close_on_empty_responseObject

Returns the value of attribute close_on_empty_response.



870
871
872
# File 'lib/net/http.rb', line 870

def close_on_empty_response
  @close_on_empty_response
end

#continue_timeoutObject

Seconds to wait for 100 Continue response. If the HTTP object does not receive a response in this many seconds it sends the request body. The default value is nil.



845
846
847
# File 'lib/net/http.rb', line 845

def continue_timeout
  @continue_timeout
end

#extra_chain_certObject

Sets the extra X509 certificates to be added to the certificate chain. See OpenSSL::SSL::SSLContext#extra_chain_cert=



945
946
947
# File 'lib/net/http.rb', line 945

def extra_chain_cert
  @extra_chain_cert
end

#ignore_eofObject

Whether to ignore EOF when reading response bodies with defined Content-Length headers. For backwards compatibility, the default is true.



861
862
863
# File 'lib/net/http.rb', line 861

def ignore_eof
  @ignore_eof
end

#keep_alive_timeoutObject

Seconds to reuse the connection of the previous request. If the idle time is less than this Keep-Alive Timeout, Net::HTTP reuses the TCP/IP socket used by the previous communication. The default value is 2 seconds.



857
858
859
# File 'lib/net/http.rb', line 857

def keep_alive_timeout
  @keep_alive_timeout
end

#keyObject

Sets an OpenSSL::PKey::RSA or OpenSSL::PKey::DSA object. (This method is appeared in Michal Rokos’s OpenSSL extension.)



949
950
951
# File 'lib/net/http.rb', line 949

def key
  @key
end

#local_hostObject

The local host used to establish the connection.



761
762
763
# File 'lib/net/http.rb', line 761

def local_host
  @local_host
end

#local_portObject

The local port used to establish the connection.



764
765
766
# File 'lib/net/http.rb', line 764

def local_port
  @local_port
end

#max_retriesObject

Returns the value of attribute max_retries.



828
829
830
# File 'lib/net/http.rb', line 828

def max_retries
  @max_retries
end

#max_versionObject

Sets the maximum SSL version. See OpenSSL::SSL::SSLContext#max_version=



961
962
963
# File 'lib/net/http.rb', line 961

def max_version
  @max_version
end

#min_versionObject

Sets the minimum SSL version. See OpenSSL::SSL::SSLContext#min_version=



958
959
960
# File 'lib/net/http.rb', line 958

def min_version
  @min_version
end

#open_timeoutObject

Number of seconds to wait for the connection to open. Any number may be used, including Floats for fractional seconds. If the HTTP object cannot open a connection in this many seconds, it raises a Net::OpenTimeout exception. The default value is 60 seconds.



799
800
801
# File 'lib/net/http.rb', line 799

def open_timeout
  @open_timeout
end

#portObject (readonly)

The port number to connect to.



758
759
760
# File 'lib/net/http.rb', line 758

def port
  @port
end

#proxy_addressObject Also known as: proxyaddr

The address of the proxy server, if one is configured.



1224
1225
1226
1227
1228
1229
1230
# File 'lib/net/http.rb', line 1224

def proxy_address
  if @proxy_from_env then
    proxy_uri&.hostname
  else
    @proxy_address
  end
end

#proxy_from_env=(value) ⇒ Object (writeonly)

Sets the attribute proxy_from_env

Parameters:

  • value

    the value to set the attribute proxy_from_env to.



778
779
780
# File 'lib/net/http.rb', line 778

def proxy_from_env=(value)
  @proxy_from_env = value
end

#proxy_passObject

The password of the proxy server, if one is configured.



1252
1253
1254
1255
1256
1257
1258
1259
# File 'lib/net/http.rb', line 1252

def proxy_pass
  if @proxy_from_env
    pass = proxy_uri&.password
    unescape(pass) if pass
  else
    @proxy_pass
  end
end

#proxy_portObject Also known as: proxyport

The port of the proxy server, if one is configured.



1233
1234
1235
1236
1237
1238
1239
# File 'lib/net/http.rb', line 1233

def proxy_port
  if @proxy_from_env then
    proxy_uri&.port
  else
    @proxy_port
  end
end

#proxy_userObject

The username of the proxy server, if one is configured.



1242
1243
1244
1245
1246
1247
1248
1249
# File 'lib/net/http.rb', line 1242

def proxy_user
  if @proxy_from_env
    user = proxy_uri&.user
    unescape(user) if user
  else
    @proxy_user
  end
end

#read_timeoutObject

Number of seconds to wait for one block to be read (via one read(2) call). Any number may be used, including Floats for fractional seconds. If the HTTP object cannot read data in this many seconds, it raises a Net::ReadTimeout exception. The default value is 60 seconds.



805
806
807
# File 'lib/net/http.rb', line 805

def read_timeout
  @read_timeout
end

#response_body_encodingObject

The encoding to use for the response body. If Encoding, uses the specified encoding. If other true value, tries to detect the response body encoding.



769
770
771
# File 'lib/net/http.rb', line 769

def response_body_encoding
  @response_body_encoding
end

#ssl_timeoutObject

Sets the SSL timeout seconds.



952
953
954
# File 'lib/net/http.rb', line 952

def ssl_timeout
  @ssl_timeout
end

#ssl_versionObject

Sets the SSL version. See OpenSSL::SSL::SSLContext#ssl_version=



955
956
957
# File 'lib/net/http.rb', line 955

def ssl_version
  @ssl_version
end

#verify_callbackObject

Sets the verify callback for the server certification verification.



964
965
966
# File 'lib/net/http.rb', line 964

def verify_callback
  @verify_callback
end

#verify_depthObject

Sets the maximum depth for the certificate chain verification.



967
968
969
# File 'lib/net/http.rb', line 967

def verify_depth
  @verify_depth
end

#verify_hostnameObject

Sets to check the server certificate is valid for the hostname. See OpenSSL::SSL::SSLContext#verify_hostname=



977
978
979
# File 'lib/net/http.rb', line 977

def verify_hostname
  @verify_hostname
end

#verify_modeObject

Sets the flags for server the certification verification at beginning of SSL/TLS session.

OpenSSL::SSL::VERIFY_NONE or OpenSSL::SSL::VERIFY_PEER are acceptable.



973
974
975
# File 'lib/net/http.rb', line 973

def verify_mode
  @verify_mode
end

#write_timeoutObject

Number of seconds to wait for one block to be written (via one write(2) call). Any number may be used, including Floats for fractional seconds. If the HTTP object cannot write data in this many seconds, it raises a Net::WriteTimeout exception. The default value is 60 seconds. Net::WriteTimeout is not raised on Windows.



812
813
814
# File 'lib/net/http.rb', line 812

def write_timeout
  @write_timeout
end

Class Method Details

.default_portObject

The default port to use for HTTP requests; defaults to 80.



532
533
534
# File 'lib/net/http.rb', line 532

def HTTP.default_port
  http_default_port()
end

.get(uri_or_host, path_or_headers = nil, port = nil) ⇒ Object

:call-seq:

Net::HTTP.get(hostname, path, port = 80) -> body
Net::HTTP:get(uri, headers = {}, port = uri.port) -> body

Sends a GET request and returns the HTTP response body as a string.

With string arguments hostname and path:

hostname = 'jsonplaceholder.typicode.com'
path = '/todos/1'
puts Net::HTTP.get(hostname, path)

Output:

{
  "userId": 1,
  "id": 1,
  "title": "delectus aut autem",
  "completed": false
}

With URI object uri and optional hash argument headers:

uri = URI('https://jsonplaceholder.typicode.com/todos/1')
headers = {'Content-type' => 'application/json; charset=UTF-8'}
Net::HTTP.get(uri, headers)


455
456
457
# File 'lib/net/http.rb', line 455

def HTTP.get(uri_or_host, path_or_headers = nil, port = nil)
  get_response(uri_or_host, path_or_headers, port).body
end

.get_print(uri_or_host, path_or_headers = nil, port = nil) ⇒ Object

:call-seq:

Net::HTTP.get_print(hostname, path, port = 80) -> nil
Net::HTTP:get_print(uri, headers = {}, port = uri.port) -> nil

Like Net::HTTP.get, but writes the returned body to $stdout; returns nil.



419
420
421
422
423
424
425
426
# File 'lib/net/http.rb', line 419

def HTTP.get_print(uri_or_host, path_or_headers = nil, port = nil)
  get_response(uri_or_host, path_or_headers, port) {|res|
    res.read_body do |chunk|
      $stdout.print chunk
    end
  }
  nil
end

.get_response(uri_or_host, path_or_headers = nil, port = nil, &block) ⇒ Object

:call-seq:

Net::HTTP.get_response(hostname, path, port = 80) -> http_response
Net::HTTP:get_response(uri, headers = {}, port = uri.port) -> http_response

Like Net::HTTP.get, but returns an Net::HTTPResponse object instead of the body string.



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/net/http.rb', line 465

def HTTP.get_response(uri_or_host, path_or_headers = nil, port = nil, &block)
  if path_or_headers && !path_or_headers.is_a?(Hash)
    host = uri_or_host
    path = path_or_headers
    new(host, port || HTTP.default_port).start {|http|
      return http.request_get(path, &block)
    }
  else
    uri = uri_or_host
    headers = path_or_headers
    start(uri.hostname, uri.port,
          :use_ssl => uri.scheme == 'https') {|http|
      return http.request_get(uri, headers, &block)
    }
  end
end

.http_default_portObject

The default port to use for HTTP requests; defaults to 80.



537
538
539
# File 'lib/net/http.rb', line 537

def HTTP.http_default_port
  80
end

.https_default_portObject

The default port to use for HTTPS requests; defaults to 443.



542
543
544
# File 'lib/net/http.rb', line 542

def HTTP.https_default_port
  443
end

.new(address, port = nil, p_addr = :ENV, p_port = nil, p_user = nil, p_pass = nil, p_no_proxy = nil) ⇒ Object

Creates a new Net::HTTP object without opening a TCP connection or HTTP session.

The address should be a DNS hostname or IP address, the port is the port the server operates on. If no port is given the default port for HTTP or HTTPS is used.

If none of the p_ arguments are given, the proxy host and port are taken from the http_proxy environment variable (or its uppercase equivalent) if present. If the proxy requires authentication you must supply it by hand. See URI::Generic#find_proxy for details of proxy detection from the environment. To disable proxy detection set p_addr to nil.

If you are connecting to a custom proxy, p_addr specifies the DNS name or IP address of the proxy host, p_port the port to use to access the proxy, p_user and p_pass the username and password if authorization is required to use the proxy, and p_no_proxy hosts which do not use the proxy.



671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
# File 'lib/net/http.rb', line 671

def HTTP.new(address, port = nil, p_addr = :ENV, p_port = nil, p_user = nil, p_pass = nil, p_no_proxy = nil)
  http = super address, port

  if proxy_class? then # from Net::HTTP::Proxy()
    http.proxy_from_env = @proxy_from_env
    http.proxy_address  = @proxy_address
    http.proxy_port     = @proxy_port
    http.proxy_user     = @proxy_user
    http.proxy_pass     = @proxy_pass
  elsif p_addr == :ENV then
    http.proxy_from_env = true
  else
    if p_addr && p_no_proxy && !URI::Generic.use_proxy?(p_addr, p_addr, p_port, p_no_proxy)
      p_addr = nil
      p_port = nil
    end
    http.proxy_address = p_addr
    http.proxy_port    = p_port || default_port
    http.proxy_user    = p_user
    http.proxy_pass    = p_pass
  end

  http
end

.newobjObject

:nodoc:



648
# File 'lib/net/http.rb', line 648

alias newobj new

.post(url, data, header = nil) ⇒ Object

Posts data to the specified URI object.

Example:

require 'net/http'
require 'uri'

Net::HTTP.post URI('http://www.example.com/api/search'),
               { "q" => "ruby", "max" => "50" }.to_json,
               "Content-Type" => "application/json"


493
494
495
496
497
498
# File 'lib/net/http.rb', line 493

def HTTP.post(url, data, header = nil)
  start(url.hostname, url.port,
        :use_ssl => url.scheme == 'https' ) {|http|
    http.post(url, data, header)
  }
end

.post_form(url, params) ⇒ Object

Posts HTML form data to the specified URI object. The form data must be provided as a Hash mapping from String to String. Example:

{ "cmd" => "search", "q" => "ruby", "max" => "50" }

This method also does Basic Authentication if and only if url.user exists. But userinfo for authentication is deprecated (RFC3986). So this feature will be removed.

Example:

require 'net/http'

Net::HTTP.post_form URI('http://www.example.com/search.cgi'),
                    { "q" => "ruby", "max" => "50" }


517
518
519
520
521
522
523
524
525
# File 'lib/net/http.rb', line 517

def HTTP.post_form(url, params)
  req = Post.new(url)
  req.form_data = params
  req.basic_auth url.user, url.password if url.user
  start(url.hostname, url.port,
        :use_ssl => url.scheme == 'https' ) {|http|
    http.request(req)
  }
end

.Proxy(p_addr = :ENV, p_port = nil, p_user = nil, p_pass = nil) ⇒ Object

Creates an HTTP proxy class which behaves like Net::HTTP, but performs all access via the specified proxy.

This class is obsolete. You may pass these same parameters directly to Net::HTTP.new. See Net::HTTP.new for details of the arguments.



1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
# File 'lib/net/http.rb', line 1163

def HTTP.Proxy(p_addr = :ENV, p_port = nil, p_user = nil, p_pass = nil)
  return self unless p_addr

  Class.new(self) {
    @is_proxy_class = true

    if p_addr == :ENV then
      @proxy_from_env = true
      @proxy_address = nil
      @proxy_port    = nil
    else
      @proxy_from_env = false
      @proxy_address = p_addr
      @proxy_port    = p_port || default_port
    end

    @proxy_user = p_user
    @proxy_pass = p_pass
  }
end

.proxy_class?Boolean

returns true if self is a class which was created by HTTP::Proxy.

Returns:

  • (Boolean)


1186
1187
1188
# File 'lib/net/http.rb', line 1186

def proxy_class?
  defined?(@is_proxy_class) ? @is_proxy_class : false
end

.socket_typeObject

:nodoc: obsolete



546
547
548
# File 'lib/net/http.rb', line 546

def HTTP.socket_type   #:nodoc: obsolete
  BufferedIO
end

.start(address, *arg, &block) ⇒ Object

:call-seq:

HTTP.start(address, port, p_addr, p_port, p_user, p_pass) {|http| ... }
HTTP.start(address, port=nil, p_addr=:ENV, p_port=nil, p_user=nil, p_pass=nil, opt) {|http| ... }

Creates a new Net::HTTP object, opens a TCP connection and HTTP session.

Argument address is the hostname or IP address of the server.

With a block given:

  • Passes the object to the given block, which may make any number of requests to the host.

  • Closes the HTTP session on block exit.

  • Returns the block’s value.

Example:

hostname = 'jsonplaceholder.typicode.com'
Net::HTTP.start(hostname) do |http|
  puts http.get('/todos/1').body
  puts http.get('/todos/2').body
end

Output:

{
  "userId": 1,
  "id": 1,
  "title": "delectus aut autem",
  "completed": false
}
{
  "userId": 1,
  "id": 2,
  "title": "quis ut nam facilis et officia qui",
  "completed": false
}

With no block given, returns the Net::HTTP object; the caller should call #finish to close the session.

Other arguments:

  • port: Server port number.

  • p_addr: Proxy address.

  • p_port: Proxy port.

  • p_user: Proxy user name.

  • p_pass: Proxy password.

  • opts: Optional options hash.

The options hash opts sets certain values, where each key is a method or accessor to be called, and its value is the value to be set.

The keys may include:

  • #ca_file

  • #ca_path

  • #cert

  • #cert_store

  • #ciphers

  • #close_on_empty_response

  • ipaddr (calls #ipaddr=)

  • #keep_alive_timeout

  • #key

  • #open_timeout

  • #read_timeout

  • #ssl_timeout

  • #ssl_version

  • use_ssl (calls #use_ssl=)

  • #verify_callback

  • #verify_depth

  • #verify_mode

  • #write_timeout



625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
# File 'lib/net/http.rb', line 625

def HTTP.start(address, *arg, &block) # :yield: +http+
  arg.pop if opt = Hash.try_convert(arg[-1])
  port, p_addr, p_port, p_user, p_pass = *arg
  p_addr = :ENV if arg.size < 2
  port = https_default_port if !port && opt && opt[:use_ssl]
  http = new(address, port, p_addr, p_port, p_user, p_pass)
  http.ipaddr = opt[:ipaddr] if opt && opt[:ipaddr]

  if opt
    if opt[:use_ssl]
      opt = {verify_mode: OpenSSL::SSL::VERIFY_PEER}.update(opt)
    end
    http.methods.grep(/\A(\w+)=\z/) do |meth|
      key = $1.to_sym
      opt.key?(key) or next
      http.__send__(meth, opt[key])
    end
  end

  http.start(&block)
end

.version_1_1?Boolean Also known as: is_version_1_1?

Returns false; retained for compatibility.

Returns:

  • (Boolean)


404
405
406
# File 'lib/net/http.rb', line 404

def HTTP.version_1_1?  #:nodoc:
  false
end

.version_1_2Object

Returns true; retained for compatibility.



394
395
396
# File 'lib/net/http.rb', line 394

def HTTP.version_1_2
  true
end

.version_1_2?Boolean Also known as: is_version_1_2?

Returns true; retained for compatibility.

Returns:

  • (Boolean)


399
400
401
# File 'lib/net/http.rb', line 399

def HTTP.version_1_2?
  true
end

Instance Method Details

#copy(path, initheader = nil) ⇒ Object

Sends a COPY request to the path and gets a response, as an HTTPResponse object.



1448
1449
1450
# File 'lib/net/http.rb', line 1448

def copy(path, initheader = nil)
  request(Copy.new(path, initheader))
end

#delete(path, initheader = {'Depth' => 'Infinity'}) ⇒ Object

Sends a DELETE request to the path and gets a response, as an HTTPResponse object.



1436
1437
1438
# File 'lib/net/http.rb', line 1436

def delete(path, initheader = {'Depth' => 'Infinity'})
  request(Delete.new(path, initheader))
end

#finishObject

Finishes the HTTP session and closes the TCP connection. Raises IOError if the session has not been started.

Raises:

  • (IOError)


1132
1133
1134
1135
# File 'lib/net/http.rb', line 1132

def finish
  raise IOError, 'HTTP session not yet started' unless started?
  do_finish
end

#get(path, initheader = nil, dest = nil, &block) ⇒ Object

Retrieves data from path on the connected-to host which may be an absolute path String or a URI to extract the path from.

initheader must be a Hash like { ‘Accept’ => ‘/’, … }, and it defaults to an empty hash. If initheader doesn’t have the key ‘accept-encoding’, then a value of “gzip;q=1.0,deflate;q=0.6,identity;q=0.3” is used, so that gzip compression is used in preference to deflate compression, which is used in preference to no compression. Ruby doesn’t have libraries to support the compress (Lempel-Ziv) compression, so that is not supported. The intent of this is to reduce bandwidth by default. If this routine sets up compression, then it does the decompression also, removing the header as well to prevent confusion. Otherwise it leaves the body as it found it.

This method returns a Net::HTTPResponse object.

If called with a block, yields each fragment of the entity body in turn as a string as it is read from the socket. Note that in this case, the returned response object will not contain a (meaningful) body.

dest argument is obsolete. It still works but you must not use it.

This method never raises an exception.

response = http.get('/index.html')

# using block
File.open('result.txt', 'w') {|f|
  http.get('/~foo/') do |str|
    f.write str
  end
}


1336
1337
1338
1339
1340
1341
1342
1343
# File 'lib/net/http.rb', line 1336

def get(path, initheader = nil, dest = nil, &block) # :yield: +body_segment+
  res = nil
  request(Get.new(path, initheader)) {|r|
    r.read_body dest, &block
    res = r
  }
  res
end

#head(path, initheader = nil) ⇒ Object

Gets only the header from path on the connected-to host. header is a Hash like { ‘Accept’ => ‘/’, … }.

This method returns a Net::HTTPResponse object.

This method never raises an exception.

response = nil
Net::HTTP.start('some.www.server', 80) {|http|
  response = http.head('/index.html')
}
p response['content-type']


1358
1359
1360
# File 'lib/net/http.rb', line 1358

def head(path, initheader = nil)
  request(Head.new(path, initheader))
end

#inspectObject



736
737
738
# File 'lib/net/http.rb', line 736

def inspect
  "#<#{self.class} #{@address}:#{@port} open=#{started?}>"
end

#ipaddrObject

The IP address to connect to/used to connect to



785
786
787
# File 'lib/net/http.rb', line 785

def ipaddr
  started? ?  @socket.io.peeraddr[3] : @ipaddr
end

#ipaddr=(addr) ⇒ Object

Set the IP address to connect to

Raises:

  • (IOError)


790
791
792
793
# File 'lib/net/http.rb', line 790

def ipaddr=(addr)
  raise IOError, "ipaddr value changed, but session already started" if started?
  @ipaddr = addr
end

#lock(path, body, initheader = nil) ⇒ Object

Sends a LOCK request to the path and gets a response, as an HTTPResponse object.



1412
1413
1414
# File 'lib/net/http.rb', line 1412

def lock(path, body, initheader = nil)
  request(Lock.new(path, initheader), body)
end

#mkcol(path, body = nil, initheader = nil) ⇒ Object

Sends a MKCOL request to the path and gets a response, as an HTTPResponse object.



1454
1455
1456
# File 'lib/net/http.rb', line 1454

def mkcol(path, body = nil, initheader = nil)
  request(Mkcol.new(path, initheader), body)
end

#move(path, initheader = nil) ⇒ Object

Sends a MOVE request to the path and gets a response, as an HTTPResponse object.



1442
1443
1444
# File 'lib/net/http.rb', line 1442

def move(path, initheader = nil)
  request(Move.new(path, initheader))
end

#options(path, initheader = nil) ⇒ Object

Sends a OPTIONS request to the path and gets a response, as an HTTPResponse object.



1424
1425
1426
# File 'lib/net/http.rb', line 1424

def options(path, initheader = nil)
  request(Options.new(path, initheader))
end

#patch(path, data, initheader = nil, dest = nil, &block) ⇒ Object

Sends a PATCH request to the path and gets a response, as an HTTPResponse object.



1396
1397
1398
# File 'lib/net/http.rb', line 1396

def patch(path, data, initheader = nil, dest = nil, &block) # :yield: +body_segment+
  send_entity(path, data, initheader, dest, Patch, &block)
end

#peer_certObject

Returns the X.509 certificates the server presented.



980
981
982
983
984
985
# File 'lib/net/http.rb', line 980

def peer_cert
  if not use_ssl? or not @socket
    return nil
  end
  @socket.io.peer_cert
end

#post(path, data, initheader = nil, dest = nil, &block) ⇒ Object

Posts data (must be a String) to path. header must be a Hash like { ‘Accept’ => ‘/’, … }.

This method returns a Net::HTTPResponse object.

If called with a block, yields each fragment of the entity body in turn as a string as it is read from the socket. Note that in this case, the returned response object will not contain a (meaningful) body.

dest argument is obsolete. It still works but you must not use it.

This method never raises exception.

response = http.post('/cgi-bin/search.rb', 'query=foo')

# using block
File.open('result.txt', 'w') {|f|
  http.post('/cgi-bin/search.rb', 'query=foo') do |str|
    f.write str
  end
}

You should set Content-Type: header field for POST. If no Content-Type: field given, this method uses “application/x-www-form-urlencoded” by default.



1390
1391
1392
# File 'lib/net/http.rb', line 1390

def post(path, data, initheader = nil, dest = nil, &block) # :yield: +body_segment+
  send_entity(path, data, initheader, dest, Post, &block)
end

#propfind(path, body = nil, initheader = {'Depth' => '0'}) ⇒ Object

Sends a PROPFIND request to the path and gets a response, as an HTTPResponse object.



1430
1431
1432
# File 'lib/net/http.rb', line 1430

def propfind(path, body = nil, initheader = {'Depth' => '0'})
  request(Propfind.new(path, initheader), body)
end

#proppatch(path, body, initheader = nil) ⇒ Object

Sends a PROPPATCH request to the path and gets a response, as an HTTPResponse object.



1406
1407
1408
# File 'lib/net/http.rb', line 1406

def proppatch(path, body, initheader = nil)
  request(Proppatch.new(path, initheader), body)
end

#proxy?Boolean

True if requests for this connection will be proxied

Returns:

  • (Boolean)


1205
1206
1207
# File 'lib/net/http.rb', line 1205

def proxy?
  !!(@proxy_from_env ? proxy_uri : @proxy_address)
end

#proxy_from_env?Boolean

True if the proxy for this connection is determined from the environment

Returns:

  • (Boolean)


1210
1211
1212
# File 'lib/net/http.rb', line 1210

def proxy_from_env?
  @proxy_from_env
end

#proxy_uriObject

The proxy URI determined from the environment for this connection.



1215
1216
1217
1218
1219
1220
1221
# File 'lib/net/http.rb', line 1215

def proxy_uri # :nodoc:
  return if @proxy_uri == false
  @proxy_uri ||= URI::HTTP.new(
    "http".freeze, nil, address, port, nil, nil, nil, nil, nil
  ).find_proxy || false
  @proxy_uri || nil
end

#put(path, data, initheader = nil) ⇒ Object

:nodoc:



1400
1401
1402
# File 'lib/net/http.rb', line 1400

def put(path, data, initheader = nil)   #:nodoc:
  request(Put.new(path, initheader), data)
end

#request(req, body = nil, &block) ⇒ Object

Sends an HTTPRequest object req to the HTTP server.

If req is a Net::HTTP::Post or Net::HTTP::Put request containing data, the data is also sent. Providing data for a Net::HTTP::Head or Net::HTTP::Get request results in an ArgumentError.

Returns an HTTPResponse object.

When called with a block, passes an HTTPResponse object to the block. The body of the response will not have been read yet; the block can process it using HTTPResponse#read_body, if desired.

This method never raises Net::* exceptions.



1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
# File 'lib/net/http.rb', line 1578

def request(req, body = nil, &block)  # :yield: +response+
  unless started?
    start {
      req['connection'] ||= 'close'
      return request(req, body, &block)
    }
  end
  if proxy_user()
    req.proxy_basic_auth proxy_user(), proxy_pass() unless use_ssl?
  end
  req.set_body_internal body
  res = transport_request(req, &block)
  if sspi_auth?(res)
    sspi_auth(req)
    res = transport_request(req, &block)
  end
  res
end

#request_get(path, initheader = nil, &block) ⇒ Object Also known as: get2

Sends a GET request to the path. Returns the response as a Net::HTTPResponse object.

When called with a block, passes an HTTPResponse object to the block. The body of the response will not have been read yet; the block can process it using HTTPResponse#read_body, if desired.

Returns the response.

This method never raises Net::* exceptions.

response = http.request_get('/index.html')
# The entity body is already read in this case.
p response['content-type']
puts response.body

# Using a block
http.request_get('/index.html') {|response|
  p response['content-type']
  response.read_body do |str|   # read body now
    print str
  end
}


1489
1490
1491
# File 'lib/net/http.rb', line 1489

def request_get(path, initheader = nil, &block) # :yield: +response+
  request(Get.new(path, initheader), &block)
end

#request_head(path, initheader = nil, &block) ⇒ Object Also known as: head2

Sends a HEAD request to the path and returns the response as a Net::HTTPResponse object.

Returns the response.

This method never raises Net::* exceptions.

response = http.request_head('/index.html')
p response['content-type']


1503
1504
1505
# File 'lib/net/http.rb', line 1503

def request_head(path, initheader = nil, &block)
  request(Head.new(path, initheader), &block)
end

#request_post(path, data, initheader = nil, &block) ⇒ Object Also known as: post2

Sends a POST request to the path.

Returns the response as a Net::HTTPResponse object.

When called with a block, the block is passed an HTTPResponse object. The body of that response will not have been read yet; the block can process it using HTTPResponse#read_body, if desired.

Returns the response.

This method never raises Net::* exceptions.

# example
response = http.request_post('/cgi-bin/nice.rb', 'datadatadata...')
p response.status
puts response.body          # body is already read in this case

# using block
http.request_post('/cgi-bin/nice.rb', 'datadatadata...') {|response|
  p response.status
  p response['content-type']
  response.read_body do |str|   # read body now
    print str
  end
}


1533
1534
1535
# File 'lib/net/http.rb', line 1533

def request_post(path, data, initheader = nil, &block) # :yield: +response+
  request Post.new(path, initheader), data, &block
end

#request_put(path, data, initheader = nil, &block) ⇒ Object Also known as: put2

:nodoc:



1537
1538
1539
# File 'lib/net/http.rb', line 1537

def request_put(path, data, initheader = nil, &block)   #:nodoc:
  request Put.new(path, initheader), data, &block
end

#send_request(name, path, data = nil, header = nil) ⇒ Object

Sends an HTTP request to the HTTP server. Also sends a DATA string if data is given.

Returns a Net::HTTPResponse object.

This method never raises Net::* exceptions.

response = http.send_request('GET', '/index.html')
puts response.body


1557
1558
1559
1560
1561
# File 'lib/net/http.rb', line 1557

def send_request(name, path, data = nil, header = nil)
  has_response_body = name != 'HEAD'
  r = HTTPGenericRequest.new(name,(data ? true : false),has_response_body,path,header)
  request r, data
end

#set_debug_output(output) ⇒ Object

WARNING This method opens a serious security hole. Never use this method in production code.

Sets an output stream for debugging.

http = Net::HTTP.new(hostname)
http.set_debug_output $stderr
http.start { .... }


749
750
751
752
# File 'lib/net/http.rb', line 749

def set_debug_output(output)
  warn 'Net::HTTP#set_debug_output called after HTTP started', uplevel: 1 if started?
  @debug_output = output
end

#startObject

Opens a TCP connection and HTTP session.

When this method is called with a block, it passes the Net::HTTP object to the block, and closes the TCP connection and HTTP session after the block has been executed.

When called with a block, it returns the return value of the block; otherwise, it returns self.

Raises:

  • (IOError)


996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
# File 'lib/net/http.rb', line 996

def start  # :yield: http
  raise IOError, 'HTTP session already opened' if @started
  if block_given?
    begin
      do_start
      return yield(self)
    ensure
      do_finish
    end
  end
  do_start
  self
end

#started?Boolean Also known as: active?

Returns true if the HTTP session has been started.

Returns:

  • (Boolean)


864
865
866
# File 'lib/net/http.rb', line 864

def started?
  @started
end

#trace(path, initheader = nil) ⇒ Object

Sends a TRACE request to the path and gets a response, as an HTTPResponse object.



1460
1461
1462
# File 'lib/net/http.rb', line 1460

def trace(path, initheader = nil)
  request(Trace.new(path, initheader))
end

#unlock(path, body, initheader = nil) ⇒ Object

Sends a UNLOCK request to the path and gets a response, as an HTTPResponse object.



1418
1419
1420
# File 'lib/net/http.rb', line 1418

def unlock(path, body, initheader = nil)
  request(Unlock.new(path, initheader), body)
end

#use_ssl=(flag) ⇒ Object

Turn on/off SSL. This flag must be set before starting session. If you change use_ssl value after session started, a Net::HTTP object raises IOError.



881
882
883
884
885
886
887
# File 'lib/net/http.rb', line 881

def use_ssl=(flag)
  flag = flag ? true : false
  if started? and @use_ssl != flag
    raise IOError, "use_ssl value changed, but session already started"
  end
  @use_ssl = flag
end

#use_ssl?Boolean

Returns true if SSL/TLS is being used with HTTP.

Returns:

  • (Boolean)


873
874
875
# File 'lib/net/http.rb', line 873

def use_ssl?
  @use_ssl
end