Method: Net::HTTP#request_post
- Defined in:
- lib/net/http.rb
#request_post(path, data, initheader = nil, &block) ⇒ Object Also known as: post2
Sends a POST request to the path.
Returns the response as a Net::HTTPResponse object.
When called with a block, the block is passed an HTTPResponse object. The body of that response will not have been read yet; the block can process it using HTTPResponse#read_body, if desired.
Returns the response.
This method never raises Net::* exceptions.
# example
response = http.request_post('/cgi-bin/nice.rb', 'datadatadata...')
p response.status
puts response.body # body is already read in this case
# using block
http.request_post('/cgi-bin/nice.rb', 'datadatadata...') {|response|
p response.status
p response['content-type']
response.read_body do |str| # read body now
print str
end
}
1517 1518 1519 |
# File 'lib/net/http.rb', line 1517 def request_post(path, data, initheader = nil, &block) # :yield: +response+ request Post.new(path, initheader), data, &block end |